"""Top-level package for drf-restricted-fields."""

__author__ = """Tonye Jack"""
__email__ = 'jtonye@ymail.com'
__version__ = '0.0.1'

from .mixins import RestrictedFieldsSerializerMixin

__all__ = ["RestrictedFieldsSerializerMixin"]
